<?php
/**
 * jQueryスクリプトを追加する.
 */
function add_wp_head_script() {
	// 管理画面にはスクリプトを追加しない
	if(is_admin()) return;
	// jQuery ロード
	wp_enqueue_script('jquery');
	// jQueryプラグインロード
	wp_enqueue_script('flickslide',
		get_template_directory_uri() . '/js/jquery.flickslide.js',
		array('jquery'));
}
add_action('wp_print_scripts', 'add_wp_head_script');

/**
 * 記事に挿入された画像を「中サイズ」に揃える.
 *
 * @param unknown_type $content
 * @return mixed
 */
function change_image_size($content) {
	// 変換サイズ（中サイズ）
	$replace_size = "medium";
	// Retina/iPhone 向け
	/*
	if(strpos($_SERVER['HTTP_USER_AGENT'], 'iPhone') !== false) {
		$replace_size = "large";
	}
	*/
	// 記事に添付されている画像取得
	$images = get_children(array(
			'post_parent' => get_the_ID(),
			'post_type' => 'attachment',
			'post_mime_type' => 'image',
			'order' => 'ASC'));
	// テーマで使われている全ての画像サイズを取得
	$sizes = get_intermediate_image_sizes();
	$sizes[] = 'full';
	// 記事に添付されている全ての画像とサイズのパスの変換用配列作成
	$image_from_path = array();
	$image_to_path = array();
	foreach($images as $image) {
		foreach($sizes as $size) {
			$img_from_src = wp_get_attachment_image_src($image->ID, $size);
			$img_to_src = wp_get_attachment_image_src($image->ID, $replace_size);
			$image_from_path[] = "!${img_from_src[0]}!";
			$image_to_path[] = "${img_to_src[0]}";
		}
	}
	// 画像の URL を現在動いている home_url に置換して返却
	return preg_replace($image_from_path, $image_to_path, $content);
}
add_filter('the_content', 'change_image_size', 1000);

/**
 * 月別アーカイブタイトルを日本語表記で返却する.
 *
 * @return 月別アーカイブ時のタイトル文字列
 */
function single_month_title_jp() {
	return get_query_var('year') . "年 " . get_query_var('monthnum') . "月";
}


/**
 * 存在しないページを指定された場合に 404 ページを表示する.
 */
function redirect_404() {
	// 年アーカイブページ、検索ページのリクエストを404にする
	if (!(is_year() || is_search())) return;
	global $post, $query;
	include(TEMPLATEPATH . '/404.php');
	exit;
}
add_filter('template_redirect', 'redirect_404');

/**
 * カスタムメニューにページスラッグとカテゴリスラッグを表示する
 */
function add_menu_css_class($classes, $item) {
	if($item->object == 'page') {
		$page = get_page($item->object_id);
		$classes[] = $page->post_name;
	} else if($item->object == 'cat_menu') {
		$tax = get_term($item->object_id, $item->object);
		$classes[] = $tax->slug;
	}
	return $classes;
}
add_filter('nav_menu_css_class', 'add_menu_css_class', 10, 2);

/**
 * カスタム分類アーカイブページの表示順を投稿の昇順に変更する.
 */
function reverce_tax_menu($wp_query) {
	// カスタム分類ページのメインループの条件を変更する
	if (!is_admin() && $wp_query->is_main_query() && is_tax('cat_menu')) {
		$wp_query->set('order', 'ASC');
	}
}
add_action('pre_get_posts', 'reverce_tax_menu');

/**
 * カスタム投稿、カスタム分類タイプを追加.
 */
function add_custom() {
	register_taxonomy('cat_menu', 
		// この分類はカスタム投稿 post_menu に属する
		array('post_menu'),
		array(
			// 管理画面ラベル名
			'label' => 'メニューカテゴリ',
			// 管理画面に表示する
			'show_ui' => true,
			// 分類に親子関係を持たせる
			'hierarchical' => true,
			// アーカイブページの URL を /menu/category/分類スラッグ とする
			'rewrite' => array(
				'slug' => 'menu/category', 'with_front' => false)
	));
	register_post_type('post_menu', array(
		// 管理画面ラベル名
		'label' => 'メニュー',
		// 管理画面の表示位置
		'menu_position' => 5,
		// 管理画面に表示しサイト上にも表示する
		'public' => true,
		// タイトル、内容、アイキャッチ画像、カスタムフィールドを使う
		'supports' => array(
			'title', 'editor', 'thumbnail', 'custom-fields'),
		// アーカイブページは持たない（カスタム分類のアーカイブで表示する）
		'has_archive' => false,
		// シングルページの URL を /menu/記事スラッグ とする
		'rewrite' => array(
			'slug' => 'menu', 'with_front' => false)
	));	
}
add_action('init', 'add_custom');

/**
 * カスタム投稿「メニュー」にアイキャッチ画像設定
 */
add_theme_support('post-thumbnails', array('post_menu'));
set_post_thumbnail_size(450, 450, false );
add_image_size('menu_thumbnail', 300, 225, true);
add_image_size('top_thumbnail', 150, 150, true);
add_image_size('side_thumbnail', 100, 100, true);

/**
 * 記事から最初に添付された画像を1枚を取得.
 */
function the_image($post_id) {
	$images = get_children(array(
		'post_parent' => $post_id,
		'post_type' => 'attachment',
		'post_mime_type' => 'image',
		'order' => 'ASC'));
	if(!empty($images)){
		$keys = array_keys($images);
		echo wp_get_attachment_image(array_pop($keys));
	} else {
		echo '<img src="' . get_stylesheet_directory_uri() . '/images/noimage.jpg" width="100" height="100">';
	}
}

/**
 * カテゴリ名からソートのために付与した文字列を削除する
 */
function replace_category_name($cat_name) {
	global $post;
	// 管理画面では実行しない
	if(is_admin()) return $cat_name;
	// メニュー以外の投稿タイプでは実行しない
	if(get_post_type($post->ID) != 'post_menu') return $cat_name;
	// 1:カテゴリ名形式の1:の部分を削除する
	$split = preg_split("/:/" , $cat_name);
	if($split[1] != '') {
		return $split[1];
	}
	return $cat_name;
}
add_filter('list_cats', 'replace_category_name');
add_filter('single_term_title', 'replace_category_name');

/**
 * moreタグの表記をデフォルトから変更.
 */
function change_content_more_link($output, $more_link_text){
  return '<p class="txtRight"><a href="' . get_permalink()
    . '" title="' . get_the_title() . '" class="more">'
    . $more_link_text . '</a></p>';
}
add_filter('the_content_more_link', 'change_content_more_link', 10, 2);

/**
 * RSSフィードを wp_head に出力
 */
add_theme_support('automatic-feed-links');

/**
 * 不要な wp_head() を除去する.(wp-includes/default-filters.php)
 */
remove_action('wp_head', 'wlwmanifest_link');
remove_action('wp_head', 'feed_links_extra');
remove_action('wp_head', 'rsd_link');
remove_action('wp_head', 'adjacent_posts_rel_link_wp_head');

/**
 * 記事に挿入された画像のローカル環境の URL を動作サイトの URL に変換.
 *
 * @param unknown_type $content
 * @return mixed
 */
function change_local_image_path($content) {
	$home = home_url();
	// 記事に添付されている画像取得
	$images = get_children(array(
			'post_parent' => get_the_ID(),
			'post_type' => 'attachment',
			'post_mime_type' => 'image',
			'order' => 'ASC'));
	// テーマで使われている全ての画像サイズを取得
	$sizes = get_intermediate_image_sizes();
	$sizes[] = 'full';
	// 記事に添付されている全ての画像とサイズのパスの変換用配列作成
	$image_from_path = array();
	$image_to_path = array();
	foreach($images as $image) {
		foreach($sizes as $size) {
			$img_src = wp_get_attachment_image_src($image->ID, $size);
			$image_from_path[] =
			"!" . str_replace($home, LOCAL_HOME, $img_src[0]) . "!";
			$image_to_path[] = "${img_src[0]}";
	}
}
// 画像の URL を現在動いている home_url に置換して返却
return preg_replace($image_from_path, $image_to_path, $content);
}
// ローカル環境の WP_HOME を定義
define('LOCAL_HOME', 'http://part3.cat-speak.net');
add_filter('the_content', 'change_local_image_path', 999);
?>
